@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.1601';
+our $VERSION = '0.1602';
 
 use Math::Bezier;
 use MIDI::Simple;
@@ -375,7 +375,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.1601
+version 0.1602
 
 =head1 SYNOPSIS
 
@@ -384,6 +384,7 @@ version 0.1601
  my $d = MIDI::Drummer::Tiny->new(
     file      => 'drums.mid',
     bpm       => 100,
+    volume    => 100,
     signature => '5/4',
     bars      => 8,
     kick      => 'n36', # Override default patch
@@ -402,6 +403,7 @@ version 0.1601
 
  $d->flam($d->quarter, $d->snare);
  $d->crescendo_roll([50, 127], $d->eighth, $d->thirtysecond);
+ $d->note($d->eighth, $d->crash1);
 
  # Alternate kick and snare
  $d->note($d->quarter, $d->open_hh, $_ % 2 ? $d->kick : $d->snare)
@@ -634,10 +636,18 @@ Add a drum roll to the score, where the B<patch> is played for
 duration B<length> in B<spec> notes, at increasing or decreasing
 volumes from B<start> to B<end>.
 
+If not provided the B<snare> is used for the B<patch>.
+
 If true, the B<bezier> flag will render the crescendo with a curve,
 rather than as a straight line.
 
-If not provided the B<snare> is used for the B<patch>.
+     |            *
+     |           *
+ vol |         *
+     |      *
+     |*
+     ---------------
+           time
 
 =head2 set_time_sig
 
